---
title: 步骤
---

A built-in component to display a series of steps.

## 示例

{{% steps %}}

### 第一步

这是第一步。

### 第二步

这是第二步。

### 第三步

这是第三步。

{{% /steps %}}


## 使用

将 Markdown h3 标题放入 `steps` 短代码中。

```
{{%/* steps */%}}

### Step 1

This is the first step.

### Step 2

This is the second step.

{{%/* /steps */%}}
```
